require 'iplayer/errors'
require 'iplayer/browser'
require 'iplayer/metadata'
require 'iplayer/subtitles'
require 'iplayer/downloader'
